Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(564)

Unified Diff: net/spdy/spdy_protocol.cc

Issue 723343002: Update from https://crrev.com/304121 (Closed) Base URL: git@github.com:domokit/mojo.git@master
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/spdy/spdy_protocol.h ('k') | net/spdy/spdy_proxy_client_socket_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/spdy/spdy_protocol.cc
diff --git a/net/spdy/spdy_protocol.cc b/net/spdy/spdy_protocol.cc
index d300a15fca31c7a1784778394474e15fc4bb7866..bf33d43944ab4460694ea588fe9ab6a3370c049a 100644
--- a/net/spdy/spdy_protocol.cc
+++ b/net/spdy/spdy_protocol.cc
@@ -372,9 +372,9 @@ bool SpdyConstants::IsValidRstStreamStatus(SpdyMajorVersion version,
}
*/
// ENHANCE_YOUR_CALM is the last valid status code.
if (rst_stream_status_field >
- SerializeRstStreamStatus(version, RST_STREAM_ENHANCE_YOUR_CALM)) {
+ SerializeRstStreamStatus(version, RST_STREAM_HTTP_1_1_REQUIRED)) {
return false;
}
@@ -436,6 +436,10 @@ SpdyRstStreamStatus SpdyConstants::ParseRstStreamStatus(
return RST_STREAM_CONNECT_ERROR;
case 11:
return RST_STREAM_ENHANCE_YOUR_CALM;
+ case 12:
+ return RST_STREAM_INADEQUATE_SECURITY;
+ case 13:
+ return RST_STREAM_HTTP_1_1_REQUIRED;
}
break;
}
@@ -499,6 +503,10 @@ int SpdyConstants::SerializeRstStreamStatus(
return 10;
case RST_STREAM_ENHANCE_YOUR_CALM:
return 11;
+ case RST_STREAM_INADEQUATE_SECURITY:
+ return 12;
+ case RST_STREAM_HTTP_1_1_REQUIRED:
+ return 13;
default:
LOG(DFATAL) << "Unhandled RST_STREAM status "
<< rst_stream_status;
@@ -589,6 +597,8 @@ SpdyGoAwayStatus SpdyConstants::ParseGoAwayStatus(SpdyMajorVersion version,
return GOAWAY_ENHANCE_YOUR_CALM;
case 12:
return GOAWAY_INADEQUATE_SECURITY;
+ case 13:
+ return GOAWAY_HTTP_1_1_REQUIRED;
}
break;
}
@@ -666,6 +676,7 @@ int SpdyConstants::SerializeGoAwayStatus(SpdyMajorVersion version,
case GOAWAY_CONNECT_ERROR:
case GOAWAY_ENHANCE_YOUR_CALM:
case GOAWAY_INADEQUATE_SECURITY:
+ case GOAWAY_HTTP_1_1_REQUIRED:
return 1; // PROTOCOL_ERROR.
default:
LOG(DFATAL) << "Serializing unhandled GOAWAY status " << status;
@@ -700,6 +711,8 @@ int SpdyConstants::SerializeGoAwayStatus(SpdyMajorVersion version,
return 11;
case GOAWAY_INADEQUATE_SECURITY:
return 12;
+ case GOAWAY_HTTP_1_1_REQUIRED:
+ return 13;
default:
LOG(DFATAL) << "Serializing unhandled GOAWAY status " << status;
return -1;
@@ -372,9 +372,9 @@ bool SpdyConstants::IsValidRstStreamStatus(SpdyMajorVersion version,
}
*/
- // ENHANCE_YOUR_CALM is the last valid status code.
+ // HTTP_1_1_REQUIRED is the last valid status code.
if (rst_stream_status_field >
« no previous file with comments | « net/spdy/spdy_protocol.h ('k') | net/spdy/spdy_proxy_client_socket_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698